@@ -67,6 +67,10 @@ class Connector(object):
         client = self.get_client(connection_data)
         return client.service.ObtenerPdf(rut, cfe_code, cfe_serial, cfe_number)
 
+    def get_document_report_parameters(self, connection_data, rut, cfe_code, cfe_serial, cfe_number, name_parameters, parameters):
+        client = self.get_client(connection_data)
+        return client.service.ObtenerPdfConParametros(rut, cfe_code, cfe_serial, cfe_number, nombreParametros=name_parameters, valoresParametros=parameters)
+
     def get_document_received_report(self, connection_data, rut, rut_received, cfe_code, cfe_serial, cfe_number):
         client = self.get_client(connection_data)
         return client.service.ObtenerPdfCfeRecibido(rut, rut_received, cfe_code, cfe_serial, cfe_number)
