@@ -217,6 +217,20 @@ class Manager(object):
             self.comprobante.cfe_number
         )
 
+    def get_document_report_parameters(self, name_parameters, parameters):
+
+        conn_obj = conn.Connector()
+
+        return conn_obj.get_document_report_parameters(
+            self.connection_data,
+            self.emisor.vat.number,
+            self.comprobante.cfe_code,
+            self.comprobante.cfe_serial,
+            self.comprobante.cfe_number,
+            name_parameters,
+            parameters,
+        )
+
     def get_document_received_report(self):
 
         conn_obj = conn.Connector()
@@ -568,7 +582,7 @@ class Manager(object):
             item_nro += 1
             Item[item_nro] = SubElement(Detalle, "Item")
             SubElement(Item[item_nro], "NroLinDet").text = str(item_nro)
-            if hasattr(line, 'cod_item'):
+            if hasattr(line, 'cod_item') and line.cod_item:
                 CodItem = SubElement(Item[item_nro], "CodItem")
                 SubElement(CodItem, "TpoCod").text = str(line.cod_item.tpo_cod)
                 SubElement(CodItem, "Cod").text = str(line.cod_item.cod)
