@@ -78,6 +78,12 @@ class Partner(object):
         self.dgi_sucursal_code = None
         self.email = None
 
+class CodItem(object):
+
+    def __init__(self, tpo_cod, cod):
+        self.tpo_cod = tpo_cod
+        self.cod = cod
+
 class InvoiceLine(object):
 
     def __init__(self, amount, invoice_indicator=None):
@@ -89,6 +95,7 @@ class InvoiceLine(object):
         self.uom_code = None
         self.unit_price = None
         self.include_tax = None
+        self.cod_item = None
 
 class PickingLine(object):
 
@@ -158,12 +165,4 @@ class ConnectionData(object):
         self.sucursal_code = None
         self.timeout = None
 
-
-
-
-
-
-
-
-
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
