@@ -88,6 +88,65 @@ class TestUruware(unittest.TestCase):
 
         report = Manager(connection_data, comprobante, self.emisor).get_document_report()
         assert '%PDF' in report.decode('latin-1')
+    
+    # ObtenerPdf
+    def test_get_document_report_with_parameters(self):
+
+        # ENVIO DE COMPROBANTE
+
+        # partner factura
+        partner_vat = objects.Vat(215404940014, 2)
+        invoice_partner = objects.Partner("Uruware S.A.")
+        invoice_partner.vat = partner_vat
+        invoice_partner.name = 'Uruware S.A.'
+        invoice_partner.city = 'Montevideo'
+        invoice_partner.street = 'Bv.Espana 2579'
+        invoice_partner.country_code = 'UY'
+        invoice_partner.country = 'Uruguay'
+        invoice_partner.email = 'lbaldi@openpyme.com.ar'
+
+        # creamos linea gravada tasa basica
+        line1 = objects.InvoiceLine(99, invoice_indicator=3)
+        line1.description = "Servicios de desarrollo"
+        line1.quantity = 1
+        line1.unit_price = 99
+        line1.tax = 21.78
+        line1.cod_item = objects.CodItem('INT1', 'COD1')
+
+        # creamos linea no facturable
+        line2 = objects.InvoiceLine(0.22, invoice_indicator=6)
+        line2.description = "Redondeo"
+        line2.description_extra = "Redondeo Extra"
+        line2.quantity = 1
+        line2.unit_price = 0.22
+        line2.cod_item = objects.CodItem('INT1', 'COD2')
+
+        # creamos factura
+        comprobante = objects.Invoice('invoice')
+        comprobante.document_type = 'cfc'
+        comprobante.cfe_serial = 'XA'
+        comprobante.cfe_number = random.randint(1, MAX_NUMBER_CFC)
+        comprobante.cfe_code = '211'
+        comprobante.date = '2015-01-31'
+        comprobante.payment_method = 1
+        comprobante.partner = invoice_partner
+        comprobante.cfe_type = 'eFact'
+        comprobante.invoice_lines = [line1, line2]
+        comprobante.currency = 'UYU'
+
+        Manager(self.connection_data, comprobante, self.emisor).send_document()
+
+        connection_data = objects.ConnectionData()
+        connection_data.url = 'https://test.ucfe.com.uy/Query116/WebServicesFE.svc?wsdl'
+        connection_data.user = 'FC-582@217628780017'
+        connection_data.password = 'WQyTMz7mQtAn1RKsbHUO2Q=='
+        connection_data.commerce_code = 'TRIBOL-582'
+        connection_data.sucursal_code = 1
+        connection_data.terminal_code = 'FC-582'
+        connection_data.timeout = '30000'
+
+        report = Manager(connection_data, comprobante, self.emisor).get_document_report_parameters(['reporte'], ['codigo'])
+        assert '%PDF' in report.decode('latin-1')
 
     # 6.2.2.1 Ejemplo para e-Factura
     def test_eFact_cfe_invoice(self):
